@@ -510,8 +510,7 @@ mod tests {
 
     use crate::config::Config;
     use crate::index::{Column, Line};
-    use crate::term::test::mock_term;
-    use crate::term::SizeInfo;
+    use crate::term::test::{mock_term, TermSize};
 
     #[test]
     fn regex_right() {
@@ -810,8 +809,8 @@ mod tests {
 
     #[test]
     fn wide_without_spacer() {
-        let size = SizeInfo::new(2., 2., 1., 1., 0., 0., false);
-        let mut term = Term::new(&Config::default(), size, ());
+        let size = TermSize::new(2, 2);
+        let mut term = Term::new(&Config::default(), &size, ());
         term.grid[Line(0)][Column(0)].c = 'x';
         term.grid[Line(0)][Column(1)].c = '字';
         term.grid[Line(0)][Column(1)].flags = Flags::WIDE_CHAR;
