@@ -52,7 +52,7 @@ pub enum ViMotion {
 }
 
 /// Cursor tracking vi mode position.
-#[derive(Default, Copy, Clone)]
+#[derive(Default, Copy, Clone, PartialEq, Eq)]
 pub struct ViModeCursor {
     pub point: Point,
 }
@@ -380,12 +380,14 @@ mod tests {
 
     use crate::ansi::Handler;
     use crate::config::Config;
+    use crate::event::VoidListener;
     use crate::index::{Column, Line};
-    use crate::term::{SizeInfo, Term};
+    use crate::term::test::TermSize;
+    use crate::term::Term;
 
-    fn term() -> Term<()> {
-        let size = SizeInfo::new(20., 20., 1.0, 1.0, 0.0, 0.0, false);
-        Term::new(&Config::default(), size, ())
+    fn term() -> Term<VoidListener> {
+        let size = TermSize::new(20, 20);
+        Term::new(&Config::default(), &size, VoidListener)
     }
 
     #[test]
@@ -492,7 +494,7 @@ mod tests {
         assert_eq!(cursor.point, Point::new(Line(0), Column(0)));
     }
 
-    fn motion_semantic_term() -> Term<()> {
+    fn motion_semantic_term() -> Term<VoidListener> {
         let mut term = term();
 
         term.grid_mut()[Line(0)][Column(0)].c = 'x';
